(function (Drupal, drupalSettings) {
  Drupal.behaviors.drupalorgCrosssiteCookieConsent = {
    attach: function (context) {
      if (!(context instanceof Document)) {
        return;
      }

      if (Drupal.drupalorgCrosssite.doNotTrack()) {
        return;
      }

      let gdpr, gdprEdit;
      if (
        (gdpr = context.getElementById('drupalorg-crosssite-gdpr')) &&
        !gdpr.classList.contains('processed')
      ) {
        gdpr.classList.add('processed');
        if (Drupal.drupalorgCrosssite.consentStatus() === null) {
          gdpr.classList.add('prompt');
          gdpr.addEventListener('click', function (e) {
            if (e.target.classList.contains('yes')) {
              Drupal.drupalorgCrosssite.setConsent(true);
            }
            else if (e.target.classList.contains('no')) {
              Drupal.drupalorgCrosssite.setConsent(false);
            }
            else {
              return;
            }
            gdpr.classList.remove('prompt');
          });
        }
        else {
          gdpr.classList.add(Drupal.drupalorgCrosssite.consentStatus());
        }
      }
      // Edit on /terms.
      if (
        (gdprEdit = context.getElementById('drupalorg-crosssite-gdpr-edit')) &&
        !gdprEdit.classList.contains('processed')
      ) {
        gdprEdit.classList.add('processed');
        if (Drupal.drupalorgCrosssite.consentStatus() !== null) {
          gdprEdit.classList.add('prompt');
          gdprEdit.classList.add(Drupal.drupalorgCrosssite.consentStatus());
          gdprEdit.addEventListener('click', function (e) {
            if (e.target.classList.contains('yes')) {
              Drupal.drupalorgCrosssite.setConsent(true);
            }
            else if (e.target.classList.contains('no')) {
              Drupal.drupalorgCrosssite.setConsent(false);
            }
            else {
              return;
            }
            gdprEdit.classList.remove('optin', 'optout');
            gdprEdit.classList.add(Drupal.drupalorgCrosssite.consentStatus());
          });
        }
      }
    }
  };

  Drupal.drupalorgCrosssite = {
    doNotTrack: function () {
      // Deprecated: https://developer.mozilla.org/en-US/docs/Web/API/Navigator/doNotTrack
      return navigator.doNotTrack == "yes" || navigator.doNotTrack == "1" || navigator.msDoNotTrack == "1" || window.doNotTrack == "1";
    },
    consentStatus: function () {
      return Drupal.drupalorgCrosssite.getCookie('cookieConsent');
    },
    canTrack: function () {
      return !this.doNotTrack() && (!drupalSettings.ConsentNeeded || this.consentStatus() === 'optin');
    },
    setConsent: function (consent) {
      Drupal.drupalorgCrosssite.setCookie(
        'cookieConsent',
        consent ? 'optin' : 'optout',
        consent ? 365 : 0
      );
    },
    setCookie: function(cname, cvalue, exdays) {
      if (exdays === 0) {
        document.cookie = cname + "=" + cvalue + ";path=/";
      }
      else {
        const d = new Date();
        d.setTime(d.getTime() + (exdays * 24 * 60 * 60 * 1000));
        let expires = "expires="+d.toUTCString();
        document.cookie = cname + "=" + cvalue + ";" + expires + ";path=/";
      }
    },
    getCookie: function(cname) {
      let name = cname + "=";
      let ca = document.cookie.split(';');
      for(let i = 0; i < ca.length; i++) {
        let c = ca[i];
        while (c.charAt(0) == ' ') {
          c = c.substring(1);
        }
        if (c.indexOf(name) == 0) {
          return c.substring(name.length, c.length);
        }
      }
      return null;
    }
  };

})(Drupal, drupalSettings);
