<?php

declare(strict_types=1);

namespace Drupal\drupalorg_crosssite;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\StringTranslation\TranslatableMarkup;

final class BaseFields {

  /**
   * Field names constants to be used in other classes.
   */
  public const ORIGINAL_DRUPAL_ID = 'drupal_id';

  /**
   * Return the base field info.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type.
   *
   * @return \Drupal\Core\Field\FieldStorageDefinitionInterface[]
   *   The field storage definitions.
   */
  public function baseFieldInfo(EntityTypeInterface $entity_type): array {
    $fields = [];
    if ($entity_type->id() === 'user') {
      $fields[self::ORIGINAL_DRUPAL_ID] = BaseFieldDefinition::create('integer')
        ->setTranslatable(FALSE)
        ->setRevisionable(FALSE)
        ->setLabel(new TranslatableMarkup('Drupal.org User Identifier'))
        ->setDisplayConfigurable('form', TRUE)
        ->setDisplayConfigurable('view', TRUE);
    }
    return $fields;
  }

}
