<?php

declare(strict_types=1);

namespace Drupal\drupalorg_crosssite\EventSubscriber;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\social_auth\Controller\OAuth2ControllerBase;
use Symfony\Component\Routing\RouteCollection;

/**
 * Route subscriber.
 */
final class LoginRouteSubscriber extends RouteSubscriberBase {

  /**
   * Constructor method.
   *
   * @readonly \Drupal\Component\Plugin\PluginManagerInterface $networkManager
   *   Network manager instance.
   * @readonly \Drupal\Core\Config\ConfigFactoryInterface $config
   *   Config instance.
   */
  public function __construct(
    private readonly PluginManagerInterface $networkManager,
    private readonly ConfigFactoryInterface $config
  ) {}

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection): void {
    if ($this->config->get('drupalorg_crosssite.settings')->get('disable_sso')) {
      return;
    }

    $hidden_routes = [
      'user.login.http',
      'user.login_status.http',
      'user.pass',
      'user.pass.http',
      'user.register',
      'user.well-known.change_password',
    ];
    foreach ($hidden_routes as $hidden_route) {
      $collection->get($hidden_route)
        ->setRequirement('_access', 'FALSE');
    }
    $network = $this->networkManager->createInstance('social_auth_keycloak');
    $collection->get('user.login')
      ->setDefaults([
        '_controller' => sprintf('%s::redirectToProvider', OAuth2ControllerBase::class),
      ])
      ->setDefault('network', $network)
      ->setOption('no_cache', TRUE)
      ->setMethods([
        'GET',
      ]);
  }

}
