<?php

namespace Drupal\drupalorg_crosssite\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form for DrupalOrg Cross-site.
 */
class DrupalorgCrosssiteSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'drupalorg_crosssite.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'drupalorg_crosssite_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('drupalorg_crosssite.settings');
    $form['disable_sso'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable SSO integration'),
      '#description' => $this->t('Do not use the SSO integration system.'),
      '#default_value' => $config->get('disable_sso'),
    ];
    $form['sub_site'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Is this site a sub-site from www.drupal.org?'),
      '#description' => $this->t('Whether the current site is a sub-site (api, events, localize...) from the main www.drupal.org site.'),
      '#default_value' => $config->get('sub_site'),
    ];

    $form['#theme'] = 'system_config_form';
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $values = $form_state->getValues();
    $this->config('drupalorg_crosssite.settings')
      ->set('disable_sso', $values['disable_sso'])
      ->set('sub_site', $values['sub_site'])
      ->save();
  }

}
