<?php

namespace Drupal\drupalorg_crosssite\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Url;

/**
 * Provides a 'Footer' Block for *.drupal.org sites.
 *
 * @Block(
 *   id = "drupalorg_crosssite_footer",
 *   admin_label = @Translation("drupal.org cross-site footer"),
 * )
 */
class DrupalOrgFooter extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#attached' => ['library' => ['drupalorg_crosssite/footer']],
      [
        '#attributes' => [
          'class' => ['drupal-news'],
        ],
        '#prefix' => '<h4 class="visually-hidden">' . $this->t('News items') . '</h4>',
        '#theme' => 'links',
        '#links' => [
          [
            'url' => Url::fromUri('https://www.drupal.org/news'),
            'title' => $this->t('News'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/planet', [
              'attributes' => ['title' => $this->t('News from Drupal community members')],
            ]),
            'title' => $this->t('Planet Drupal'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/about/media-kit/social-media', [
              'attributes' => ['title' => $this->t('Drupal on social media')],
            ]),
            'title' => $this->t('Social media'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/subscribe'),
            'title' => $this->t('Sign up for Drupal news'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/security', [
              'attributes' => ['title' => $this->t('Announcements from the Drupal Security Team')],
            ]),
            'title' => $this->t('Security advisories'),
          ],
          [
            'url' => Url::fromUri('https://jobs.drupal.org/', [
              'attributes' => ['title' => $this->t('Drupal Jobs')],
            ]),
            'title' => $this->t('Jobs'),
          ],
        ],
      ],
      [
        '#attributes' => [
          'class' => ['community'],
        ],
        '#prefix' => '<h4 class="visually-hidden">' . $this->t('Our community') . '</h4>',
        '#theme' => 'links',
        '#links' => [
          [
            'url' => Url::fromUri('https://www.drupal.org/community'),
            'title' => $this->t('Community'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/drupal-services', ['attributes' => ['title' => $this->t('People and organizations offering Drupal services')]]),
            'title' => $this->t('Services'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/training', ['attributes' => ['title' => $this->t('People and organizations offering Drupal training')]]),
            'title' => $this->t('Training'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/hosting', ['attributes' => ['title' => $this->t('Organizations offering Drupal hosting')]]),
            'title' => $this->t('Hosting'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/community/contributor-guide'),
            'title' => $this->t('Contributor guide'),
          ],
          [
            'url' => Url::fromUri('https://groups.drupal.org/groups', [
              'attributes' => ['title' => $this->t('groups.drupal.org')],
            ]),
            'title' => $this->t('Groups & meetups'),
          ],
          [
            'url' => Url::fromUri('https://events.drupal.org', [
              'attributes' => ['title' => $this->t('Upcoming and past DrupalCons')],
            ]),
            'title' => $this->t('DrupalCon'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/dcoc', [
              'attributes' => ['title' => $this->t('Drupal code of conduct')],
            ]),
            'title' => $this->t('Code of conduct'),
          ],
        ],
      ],
      [
        '#attributes' => [
          'class' => ['get-started'],
        ],
        '#prefix' => '<h4 class="visually-hidden">' . $this->t('Documentation') . '</h4>',
        '#theme' => 'links',
        '#links' => [
          [
            'url' => Url::fromUri('https://www.drupal.org/documentation', [
              'attributes' => ['title' => $this->t('Documentation for working with Drupal')],
            ]),
            'title' => $this->t('Documentation'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/docs'),
            'title' => $this->t('Drupal Guide'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/docs/user_guide/en/index.html'),
            'title' => $this->t('Drupal User Guide'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/documentation/develop'),
            'title' => $this->t('Developer docs'),
          ],
          [
            'url' => Url::fromUri('https://api.drupal.org/', [
              'attributes' => ['title' => $this->t('Drupal API reference')],
            ]),
            'title' => $this->t('API.Drupal.org'),
          ],
        ],
      ],
      [
        '#attributes' => [
          'class' => ['download-extend'],
        ],
        '#prefix' => '<h4 class="visually-hidden">' . $this->t('Drupal code base') . '</h4>',
        '#theme' => 'links',
        '#links' => [
          [
            'url' => Url::fromUri('https://www.drupal.org/download'),
            'title' => $this->t('Download & Extend'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/project/drupal', [
              'attributes' => ['title' => $this->t('Download the latest version of the Drupal software')],
            ]),
            'title' => $this->t('Drupal core'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/project/project_module', [
              'attributes' => ['title' => $this->t('Download add-on features and functionality')],
            ]),
            'title' => $this->t('Modules'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/project/project_theme', [
              'attributes' => ['title' => $this->t('Download pre-designed styles for Drupal')],
            ]),
            'title' => $this->t('Themes'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/project/project_distribution', [
              'attributes' => ['title' => $this->t('Download a pre-packaged Drupal site')],
            ]),
            'title' => $this->t('Distributions'),
          ],
        ],
      ],
      [
        '#attributes' => [
          'class' => ['about'],
        ],
        '#prefix' => '<h4 class="visually-hidden">' . $this->t('Governance of community') . '</h4>',
        '#theme' => 'links',
        '#links' => [
          [
            'url' => Url::fromUri('https://www.drupal.org/about'),
            'title' => $this->t('About'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/about/features/accessibility', [
              'attributes' => ['title' => $this->t('Our committment to accessibility')],
            ]),
            'title' => $this->t('Web accessibility'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/association', [
              'attributes' => ['title' => $this->t('About the Drupal Association')],
            ]),
            'title' => $this->t('Drupal Association'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/drupalorg', [
              'attributes' => ['title' => $this->t('About Drupal.org')],
            ]),
            'title' => $this->t('About Drupal.org'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/terms', [
              'attributes' => ['title' => $this->t('Drupal.org terms of service')],
            ]),
            'title' => $this->t('Terms of service'),
          ],
          [
            'url' => Url::fromUri('https://www.drupal.org/privacy', [
              'attributes' => ['title' => $this->t('Drupal.org privacy policy')],
            ]),
            'title' => $this->t('Privacy policy'),
          ],
        ],
      ],
    ];
  }

}
